@@ -9,10 +9,11 @@ void usage();
 void not_sup(char *option,char *hostname);
 char *decode_status(long stat);
 void do_general_get(SNMP_session &session, unsigned long *argflags,
-		    unsigned long &operflags);
+		    unsigned long &operflags,char **optparam);
 void do_connections(unsigned long *argflags,SNMP_session &session,
 		    ConnectionInfoRequest *cir);
-void do_hostmib_get(SNMP_session &session, unsigned long *argflags);
+void do_hostmib_get(SNMP_session &session, unsigned long *argflags,
+		    unsigned long &operflags);
 void hpcfgsrc(SNMP_session &session,unsigned long *argflags,BerBase *cfgsrc);
 
 #endif
