@@ -15,7 +15,8 @@ public:
 
   struct TableEntry *next;
 
-  TableEntry(const char *ostr,Tags thetype,unsigned int off,TableEntry *nxt);
+  TableEntry(const char *ostr,Tags thetype,unsigned int off,
+	     TableEntry *nxt);
   
   int operator==(const char *str){ return !strcmp(str,oidstr);}
 };
@@ -32,13 +33,11 @@ public:
   inline SNMP_structFiller(SNMP_session &sess): tabdef(NULL),oidseq(NULL),
     session(sess),retseq(NULL){}
 
-  // untested possibly broken
-  // SNMP_structFiller(SNMP_session &sess, unsigned int num ...); 
-
   ~SNMP_structFiller();
 
   void append(const char *oidstr,Tags tag,unsigned int offset);
   void remove(const char *oidstr);
+  void reset(){delete retseq; retseq=NULL;}
 
   void *get(void *tobefilled);
   void *get_next(void *tobefilled);
@@ -47,14 +46,11 @@ public:
 class SNMP_table:public SNMP_structFiller{
   unsigned int structlen;
 public:
-  inline SNMP_table(SNMP_session &session, unsigned int slen):structlen(slen),
-    SNMP_structFiller(session){}
+  inline SNMP_table(SNMP_session &session, unsigned int slen):
+    structlen(slen),SNMP_structFiller(session){}
 
-  // untested possibly broken
-  // SNMP_table(SNMP_session &session, unsigned int slen,unsigned int num ...);
-
-  // returns a pointer to a vector of the type defined with the data elements 
-  // filled in. needs to be freed.
+  /* returns a pointer to a vector of the type defined with the 
+     data elements filled in. needs to be freed. */
   void *get(unsigned int &len);
 };
 
